@@ -1,6 +1,6 @@
 #' Create a complete ggplot appropriate to a particular data type
 #'
-#' \code{autoplot} uses ggplot2 to draw a particular plot for an object of a
+#' `autoplot` uses ggplot2 to draw a particular plot for an object of a
 #' particular class in a single command. This defines the S3 generic that
 #' other classes and packages can extend.
 #'
@@ -8,14 +8,17 @@
 #' @param ... other arguments passed to specific methods
 #' @return a ggplot object
 #' @export
-#' @seealso \code{\link{ggplot}} and \code{\link{fortify}}
+#' @seealso [autolayer()], [ggplot()] and [fortify()]
 autoplot <- function(object, ...) {
   UseMethod("autoplot")
 }
 
 #' @export
 autoplot.default <- function(object, ...) {
-  error.msg <- paste("Objects of type",class(object),"not supported by autoplot.  Please use qplot() or ggplot() instead.\n")
-  stop(error.msg, call.=FALSE)
+  abort(glue(
+    "Objects of type ",
+    glue_collapse(class(object), "/"),
+    " not supported by autoplot."
+  ))
 }
 
