@@ -41,7 +41,9 @@
 #'   gp = factor(rep(letters[1:3], each = 10)),
 #'   y = rnorm(30)
 #' )
-#' ds <- plyr::ddply(df, "gp", plyr::summarise, mean = mean(y), sd = sd(y))
+#' ds <- do.call(rbind, lapply(split(df, df$gp), function(d) {
+#'   data.frame(mean = mean(d$y), sd = sd(d$y), gp = d$gp)
+#' }))
 #'
 #' # The summary data frame ds is used to plot larger red points on top
 #' # of the raw data. Note that we don't need to supply `data` or `mapping`
@@ -78,7 +80,7 @@ ggplot <- function(data = NULL, mapping = aes(), ...,
 ggplot.default <- function(data = NULL, mapping = aes(), ...,
                            environment = parent.frame()) {
   if (!missing(mapping) && !inherits(mapping, "uneval")) {
-    stop("Mapping should be created with `aes() or `aes_()`.", call. = FALSE)
+    abort("Mapping should be created with `aes() or `aes_()`.")
   }
 
   data <- fortify(data, ...)
@@ -104,7 +106,10 @@ ggplot.default <- function(data = NULL, mapping = aes(), ...,
 ggplot.function <- function(data = NULL, mapping = aes(), ...,
                             environment = parent.frame()) {
   # Added to avoid functions end in ggplot.default
-  stop("You're passing a function as global data.\nHave you misspelled the `data` argument in `ggplot()`", call. = FALSE)
+  abort(glue("
+    You're passing a function as global data.
+    Have you misspelled the `data` argument in `ggplot()`
+  "))
 }
 
 plot_clone <- function(plot) {
