@@ -33,7 +33,7 @@ stat_sum <- function(mapping = NULL, data = NULL,
 #' @usage NULL
 #' @export
 StatSum <- ggproto("StatSum", Stat,
-  default_aes = aes(size = stat(n), weight = 1),
+  default_aes = aes(size = after_stat(n), weight = 1),
 
   required_aes = c("x", "y"),
 
@@ -42,8 +42,8 @@ StatSum <- ggproto("StatSum", Stat,
 
     group_by <- setdiff(intersect(names(data), ggplot_global$all_aesthetics), "weight")
 
-    counts <- plyr::count(data, group_by, wt_var = "weight")
-    counts <- plyr::rename(counts, c(freq = "n"), warn_missing = FALSE)
+    counts <- count(data, group_by, wt_var = "weight")
+    counts <- rename(counts, c(freq = "n"))
     counts$prop <- stats::ave(counts$n, counts$group, FUN = prop.table)
     counts
   }
