@@ -1,25 +1,28 @@
 #' Bin and summarise in 2d (rectangle & hexagons)
 #'
-#' \code{stat_summary_2d} is a 2d variation of \code{\link{stat_summary}}.
-#' \code{stat_summary_hex} is a hexagonal variation of
-#' \code{\link{stat_summary_2d}}. The data are divided into bins defined
-#' by \code{x} and \code{y}, and then the values of \code{z} in each cell is
-#' are summarised with \code{fun}.
+#' `stat_summary_2d` is a 2d variation of [stat_summary()].
+#' `stat_summary_hex` is a hexagonal variation of
+#' [stat_summary_2d()]. The data are divided into bins defined
+#' by `x` and `y`, and then the values of `z` in each cell is
+#' are summarised with `fun`.
 #'
 #' @section Aesthetics:
-#' \itemize{
-#'  \item \code{x}: horizontal position
-#'  \item \code{y}: vertical position
-#'  \item \code{z}: value passed to the summary function
+#'  - `x`: horizontal position
+#'  - `y`: vertical position
+#'  - `z`: value passed to the summary function
+#' @section Computed variables:
+#' \describe{
+#'   \item{x,y}{Location}
+#'   \item{value}{Value of summary statistic.}
 #' }
-#'
-#' @seealso \code{\link{stat_summary_hex}} for hexagonal summarization.
-#'   \code{\link{stat_bin2d}} for the binning options.
-#' @inheritParams stat_identity
+#' @seealso [stat_summary_hex()] for hexagonal summarization.
+#'   [stat_bin2d()] for the binning options.
+#' @inheritParams layer
+#' @inheritParams geom_point
 #' @inheritParams stat_bin_2d
-#' @param drop drop if the output of \code{fun} is \code{NA}.
+#' @param drop drop if the output of `fun` is `NA`.
 #' @param fun function for summary.
-#' @param fun.args A list of extra arguments to pass to \code{fun}
+#' @param fun.args A list of extra arguments to pass to `fun`
 #' @export
 #' @examples
 #' d <- ggplot(diamonds, aes(carat, depth, z = price))
@@ -27,17 +30,25 @@
 #'
 #' # Specifying function
 #' d + stat_summary_2d(fun = function(x) sum(x^2))
+#' d + stat_summary_2d(fun = ~ sum(.x^2))
 #' d + stat_summary_2d(fun = var)
 #' d + stat_summary_2d(fun = "quantile", fun.args = list(probs = 0.1))
 #'
 #' if (requireNamespace("hexbin")) {
 #' d + stat_summary_hex()
+#' d + stat_summary_hex(fun = ~ sum(.x^2))
 #' }
-stat_summary_2d <- function(mapping = NULL, data = NULL, geom = "tile",
-                            position = "identity", bins = 30, binwidth = NULL,
-                            drop = TRUE, fun = "mean", fun.args = list(),
-                            na.rm = FALSE, show.legend = NA, inherit.aes = TRUE,
-                            ...) {
+stat_summary_2d <- function(mapping = NULL, data = NULL,
+                            geom = "tile", position = "identity",
+                            ...,
+                            bins = 30,
+                            binwidth = NULL,
+                            drop = TRUE,
+                            fun = "mean",
+                            fun.args = list(),
+                            na.rm = FALSE,
+                            show.legend = NA,
+                            inherit.aes = TRUE) {
   layer(
     data = data,
     mapping = mapping,
@@ -71,7 +82,7 @@ stat_summary2d <- function(...) {
 #' @usage NULL
 #' @export
 StatSummary2d <- ggproto("StatSummary2d", Stat,
-  default_aes = aes(fill = ..value..),
+  default_aes = aes(fill = after_stat(value)),
 
   required_aes = c("x", "y", "z"),
 
@@ -83,12 +94,13 @@ StatSummary2d <- ggproto("StatSummary2d", Stat,
     breaks <- dual_param(breaks, list(NULL, NULL))
     bins <- dual_param(bins, list(x = 30, y = 30))
 
-    xbreaks <- bin_breaks(scales$x, breaks$x, origin$x, binwidth$x, bins$x)
-    ybreaks <- bin_breaks(scales$y, breaks$y, origin$y, binwidth$y, bins$y)
+    xbreaks <- bin2d_breaks(scales$x, breaks$x, origin$x, binwidth$x, bins$x)
+    ybreaks <- bin2d_breaks(scales$y, breaks$y, origin$y, binwidth$y, bins$y)
 
     xbin <- cut(data$x, xbreaks, include.lowest = TRUE, labels = FALSE)
     ybin <- cut(data$y, ybreaks, include.lowest = TRUE, labels = FALSE)
 
+    fun <- as_function(fun)
     f <- function(x) {
       do.call(fun, c(list(quote(x)), fun.args))
     }
